arrc.losses.arc\_face\_loss
===========================

.. automodule:: arrc.losses.arc_face_loss

   
   .. rubric:: Functions

   .. autosummary::
   
      arcface_loss
   
   .. rubric:: Classes

   .. autosummary::
   
      ArcFaceLoss
   